@@ -5,13 +5,13 @@ package Chart::GGPlot::Backend::Plotly;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0004_02'; # TRIAL VERSION
+our $VERSION = '0.0010_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend);
 
-use Chart::Plotly 0.025 qw(show_plot);
+use Chart::Plotly qw(show_plot);
 use Chart::Plotly::Plot;
-use Chart::Plotly::Image::Orca;
+use Chart::Plotly::Image;
 
 use Data::Munge qw(elem);
 use JSON;
@@ -393,7 +393,9 @@ method _to_plotly ($plot_built) {
                 ) ? ( showgrid => JSON::false, )
                 : (
                     gridcolor => to_rgb( $el_panel_grid->at('color') ),
-                    gridwidth => to_rgb( $el_panel_grid->at('size') ),
+
+                    # FIXME: fix this and use cex_to_px()
+                    gridwidth => $el_panel_grid->at('size'),
                 )
             ),
         };
@@ -534,6 +536,7 @@ method _to_plotly ($plot_built) {
 
     #$log->trace( "plotly html:\n" . $plotly->html ) if $log->is_trace;
 
+    $plotly->{config}{responsive} = JSON::true;
     return $plotly;
 }
 
@@ -545,20 +548,29 @@ method ggplotly ($ggplot) {
 
 method show ($ggplot, HashRef $opts={}) {
     my $plotly = $self->ggplotly($ggplot);
+    if ( $opts->{width} or $opts->{height} ) {
+        $plotly->{layout}{width}  = $opts->{width}  if ( $opts->{width} );
+        $plotly->{layout}{height} = $opts->{height} if ( $opts->{height} );
+        $plotly->{config}{responsive} = JSON::false;
+    }
+    else {
+        $plotly->{config}{responsive} = JSON::true;
+    }
     show_plot( $plotly );
 }
 
 method save ($ggplot, $filename, HashRef $opts={}) {
     my $plotly = $self->ggplotly($ggplot);
-    my $good = Chart::Plotly::Image::Orca::orca(
+    my %opts = %$opts;
+    
+    my $good = Chart::Plotly::Image::save_image(
         #<<< no perltidy
                 plot => $plotly,
                 file => $filename,
-        maybe   width => $opts->{width},
-        maybe   height => $opts->{height},
+                %opts,
         #>>>
     );
-    die "Failed to save image via plotly-orca" unless $good;
+    die "Failed to save image" unless $good;
 }
 
 method iplot ($ggplot, HashRef $opts={}) {
@@ -585,7 +597,7 @@ Chart::GGPlot::Backend::Plotly - Plotly backend for Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0004_02
+version 0.0010_01
 
 =head1 DESCRIPTION
 
@@ -612,12 +624,32 @@ C<BROWSER> to force a browser command on your system, for example,
 
     export BROWSER=chromium-browser
 
+Below options are supported for C<$opts>:
+
+=over 4
+
+=item *
+
+width: plot width in pixel
+
+=item *
+
+height: plot height in pixel
+
+=back
+
+If neither C<width> or C<height> is not specified, the plotly shown in browser
+will use L<fluid layout|https://plot.ly/javascript/responsive-fluid-layout/>,
+that is, figure size will be automatically resized when browser window size
+changes.
+
 =head2 save
 
     save($ggplot, $filename, HashRef $opts={})
 
 Export the plot to a static image file. This internally uses
-L<Chart::Plotly::Image::Orca>.
+L<Chart::Plotly::Image>. And to get L<Chart::Plotly::Image>
+to work, I recommend you install L<Chart::Kaleido::Plotly>.
 
 Below options are supported for C<$opts>:
 
@@ -625,11 +657,11 @@ Below options are supported for C<$opts>:
 
 =item *
 
-width
+width: plot width in pixel
 
 =item *
 
-height
+height: plot height in pixel
 
 =back
 
@@ -645,7 +677,7 @@ L<https://plot.ly/|Plotly>
 
 L<Chart::GGPlot::Backend>
 
-L<Chart::Plotly>, L<Chart::Plotly::Image::Orca>
+L<Chart::Plotly>, L<Chart::Plotly::Image>, L<Chart::Kaleido::Plotly>
 
 =head1 AUTHOR
 
