@@ -5,7 +5,7 @@ package Chart::GGPlot::Geom;
 use Chart::GGPlot::Role qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0004_02'; # TRIAL VERSION
+our $VERSION = '0.0010_01'; # TRIAL VERSION
 
 use Data::Frame::Util qw(guess_and_convert_to_pdl);
 use Types::Standard qw(ArrayRef CodeRef);
@@ -95,7 +95,14 @@ Chart::GGPlot::Geom - The geom role
 
 =head1 VERSION
 
-version 0.0004_02
+version 0.0010_01
+
+=head1 DESCRIPTION
+
+This module is a Moose role for "geom".
+
+For users of Chart::GGPlot you would mostly want to look at
+L<Chart::GGPlot::Geom::Functions> instead.
 
 =head1 AUTHOR
 
