@@ -5,7 +5,7 @@ package Chart::GGPlot::Stat;
 use Chart::GGPlot::Role qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0004_02'; # TRIAL VERSION
+our $VERSION = '0.0010_01'; # TRIAL VERSION
 
 use List::AllUtils qw(reduce pairmap);
 use Types::Standard qw(ArrayRef CodeRef Str InstanceOf Bool);
@@ -59,9 +59,7 @@ method compute_layer ( $data, $params, $layout ) {
                     return $self->compute_panel( $d, $scales, $params );
                 }
                 catch {
-                    warn
-                      sprintf( "Computation failed in '%s': $@", ref($self) );
-                    return;
+                    die sprintf( "Computation failed in '%s': $@", ref($self) );
                 }
             }
         )->flatten
@@ -119,7 +117,14 @@ Chart::GGPlot::Stat - The stat role
 
 =head1 VERSION
 
-version 0.0004_02
+version 0.0010_01
+
+=head1 DESCRIPTION
+
+This module is a Moose role for "stats".
+
+For users of Chart::GGPlot you would mostly want to look at
+L<Chart::GGPlot::Stat::Functions> instead.
 
 =head1 AUTHOR
 
