@@ -6,7 +6,7 @@ use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 use MooseX::Singleton;
 
-our $VERSION = '0.0004_02'; # TRIAL VERSION
+our $VERSION = '0.0010_01'; # TRIAL VERSION
 
 use Data::Frame;
 use Module::Load;
@@ -291,14 +291,22 @@ Chart::GGPlot::Stat::Smooth - Statistic method that does smoothing
 
 =head1 VERSION
 
-version 0.0004_02
+version 0.0010_01
+
+=head1 DESCRIPTION
+
+Some of the stats methods may require additional modules be installed. For
+example the C<"loess"> method requires L<Math::LOESS>. At present those
+dependencies are specified as "recommends" instead of "requires" of the 
+C<Chart-GGPlot> distribution on CPAN. So depending on your cpan client
+they may or may not be installed when you tell your cpan client to install
+Chart::GGPlot. If you see errors about missing modules, you can install
+the modules.
 
 =head1 SEE ALSO
 
 L<Chart::GGPlot::Stat>, L<Chart::GGPlot::Util::Stats>
 
-L<Math::LOESS>
-
 =head1 AUTHOR
 
 Stephan Loyd <sloyd@cpan.org>
