@@ -4,7 +4,7 @@ package Chart::GGPlot::Util::Stats;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0004_02'; # TRIAL VERSION
+our $VERSION = '0.0010_01'; # TRIAL VERSION
 
 use parent qw(Exporter::Tiny);
 
@@ -14,7 +14,9 @@ use Module::Load;
 our @EXPORT_OK = qw(loess glm);
 
 
-fun loess (:$x, :$y, :$weights, :$xseq, :$se, :$level, :$span,
+fun loess (:$x, :$y, :$weights, :$xseq,
+           :$span=0.75,
+           :$se=false, :$level=0.95,
            :$degree=undef, :$parametric=undef,
            :$drop_square=undef, :$normalize=undef,
            :$family=undef) {
@@ -45,7 +47,8 @@ fun loess (:$x, :$y, :$weights, :$xseq, :$se, :$level, :$span,
 }
 
 
-fun glm (:$x, :$y, :$xseq, :$se, :$level,
+fun glm (:$x, :$y, :$xseq,
+         :$se=false, :$level=0.95,
          :$family='gaussian', %rest) {
     load PDL::Stats::GLM;
     load PDL::GSL::CDF;
@@ -94,18 +97,39 @@ Chart::GGPlot::Util::Stats - Utility statistics functions
 
 =head1 VERSION
 
-version 0.0004_02
+version 0.0010_01
 
 =head1 DESCRIPTION
 
 Functions in this module are used by L<Chart::GGPlot::Stat::Smooth>.
 
+Each function returns a L<Data::Frame> object which has a column named
+C<"fit"> for smooth fit values for given argument C<$xseq>. And if argument
+C<$se> is a true value, the result data frame would have additonal two
+columns C<"ymin"> and C<"ymax"> for confidence interval.
+
 =head1 FUNCTIONS
 
 =head2 loess
 
+    loess(:$x, :$y, :$weights, :$xseq,
+          :$span=0.75,
+          :$se=false, :$level=0.95,
+          :$degree=2, :$parametric=undef, :$drop_square=undef,
+          :$normalize=true, :$family='gaussian')
+
+This function requires L<Math::LOESS>.
+
+See L<Math::LOESS::Model> for details of the arguments.
+
 =head2 glm
 
+    glm(:$x, :$y, :$xseq,
+        :$se=false, :$level=0.95,
+        $family='gaussian')
+
+This function requires L<PDL::Stats::GLM> and L<PDL::GSL::CDF>.
+
 =head1 SEE ALSO
 
 L<Chart::GGPlot::Stat::Smooth>
